[colorjs]: https://github.com/LeaVerou/color.js
[compositing-level-1]: https://www.w3.org/TR/compositing-1/
[css-spec-convert]: https://drafts.csswg.org/css-color/#color-conversion-code
[de76]: http://www.brucelindbloom.com/index.html?Math.html
[de94]: http://www.brucelindbloom.com/index.html?Math.html
[de2000]: http://www.brucelindbloom.com/index.html?Math.html
[decmc]: http://www.brucelindbloom.com/index.html?Math.html
[deitp]: https://kb.portrait.com/help/ictcp-color-difference-metric
[dez]: https://www.osapublishing.org/oe/fulltext.cfm?uri=oe-25-13-15131&id=368272
[de99o]: https://de.wikipedia.org/wiki/DIN99-Farbraum
[dehyab]: http://markfairchild.org/PDFs/PAP40.pdf
[floating-point]: https://docs.python.org/3/tutorial/floatingpoint.html#floating-point-arithmetic-issues-and-limitations
[issues]: https://github.com/facelessuser/coloraide/issues
[lch-chroma]: https://colorjs.io/docs/gamut-mapping.html#so-how-does-colorjs-handle-all-this
[porter-duff]: https://www.w3.org/TR/compositing-1/#porterduffcompositingoperators
[source-over]: https://www.w3.org/TR/compositing-1/#porterduffcompositingoperators_srcover
